@@ -4,7 +4,7 @@ package LWP::Protocol::Coro::http;
 use strict;
 use warnings;
 
-use version; our $VERSION = qv('v1.0.5');
+use version; our $VERSION = qv('v1.0.6');
 
 use AnyEvent::HTTP qw( http_request );
 use Coro::Channel  qw( );
@@ -38,6 +38,10 @@ sub _set_response_headers {
       ];
    }
 
+   # Imitate Net::HTTP's removal of newlines.
+   s/\s*\n\s+/ /g
+      for values %headers;
+
    $response->header(%headers);
 }
 
@@ -127,7 +131,7 @@ LWP::Protocol::Coro::http - Coro-friendly HTTP and HTTPS backend for LWP
 
 =head1 VERSION
 
-Version 1.0.5
+Version 1.0.6
 
 
 =head1 SYNOPSIS
